@@ -1,22 +1,28 @@
-package com.unciv.logic
+package com.unciv.logic.automation.civilization
 
 import com.badlogic.gdx.math.Vector2
 import com.unciv.Constants
 import com.unciv.json.HashMapVector2
+import com.unciv.logic.GameInfo
+import com.unciv.logic.IsPartOfGameInfoSerialization
 import com.unciv.logic.civilization.NotificationCategory
 import com.unciv.logic.civilization.NotificationIcon
-import com.unciv.logic.map.tile.Tile
 import com.unciv.logic.map.TileMap
+import com.unciv.logic.map.tile.Tile
 import com.unciv.models.ruleset.unique.UniqueType
 import com.unciv.ui.components.extensions.randomWeighted
-import java.util.*
 import kotlin.math.max
 import kotlin.math.min
 import kotlin.math.pow
+import kotlin.random.Random
 
 class BarbarianManager : IsPartOfGameInfoSerialization {
+    /** Deprecated  */
+    @Deprecated("by 4.6.12 due to serialization containing exact class location - replaced by encampments")
     val camps = HashMapVector2<Encampment>()
 
+    val encampments = ArrayList<Encampment>()
+
     @Transient
     lateinit var gameInfo: GameInfo
 
@@ -25,8 +31,7 @@ class BarbarianManager : IsPartOfGameInfoSerialization {
 
     fun clone(): BarbarianManager {
         val toReturn = BarbarianManager()
-        for (camp in camps.values.map { it.clone() })
-            toReturn.camps[camp.position] = camp
+        toReturn.encampments.addAll(encampments.map { it.clone() })
         return toReturn
     }
 
@@ -35,49 +40,45 @@ class BarbarianManager : IsPartOfGameInfoSerialization {
         this.tileMap = gameInfo.tileMap
 
         // Add any preexisting camps as Encampment objects
+
+        val existingEncampmentLocations = encampments.asSequence().map { it.position }.toHashSet()
+
         for (tile in tileMap.values) {
             if (tile.improvement == Constants.barbarianEncampment
-                && camps[tile.position] == null) {
-                val newCamp = Encampment(tile.position)
-                camps[newCamp.position] = newCamp
+                    && !existingEncampmentLocations.contains(tile.position)) {
+                encampments.add(Encampment(tile.position))
             }
         }
 
-        for (camp in camps.values)
+        for (camp in encampments)
             camp.gameInfo = gameInfo
     }
 
     fun updateEncampments() {
         // Check if camps were destroyed
-        val positionsToRemove = ArrayList<Vector2>()
-        for ((position, camp) in camps) {
-            if (tileMap[position].improvement != Constants.barbarianEncampment) {
-                camp.wasDestroyed()
+        for (encampment in encampments.toList()) { // tolist to avoid concurrent modification
+            if (tileMap[encampment.position].improvement != Constants.barbarianEncampment) {
+                encampment.wasDestroyed()
             }
             // Check if the ghosts are ready to depart
-            if (camp.destroyed && camp.countdown == 0)
-                positionsToRemove.add(position)
+            if (encampment.destroyed && encampment.countdown == 0)
+                encampments.remove(encampment)
         }
-        for (position in positionsToRemove)
-            camps.remove(position)
 
         // Possibly place a new encampment
         placeBarbarianEncampment()
 
-        // Update all existing camps
-        for (camp in camps.values) {
-            camp.update()
-        }
+        for (encampment in encampments) encampment.update()
     }
 
     /** Called when an encampment was attacked, will speed up time to next spawn */
     fun campAttacked(position: Vector2) {
-        camps[position]?.wasAttacked()
+        encampments.firstOrNull { it.position == position }?.wasAttacked()
     }
 
     fun placeBarbarianEncampment() {
         // Before we do the expensive stuff, do a roll to see if we will place a camp at all
-        if (gameInfo.turns > 1 && Random().nextBoolean())
+        if (gameInfo.turns > 1 && Random.Default.nextBoolean())
             return
 
         // Barbarians will only spawn in places that no one can see
@@ -88,7 +89,7 @@ class BarbarianManager : IsPartOfGameInfoSerialization {
         val fogTilesPerCamp = (tileMap.values.size.toFloat().pow(0.4f)).toInt() // Approximately
 
         // Check if we have more room
-        var campsToAdd = (fogTiles.size / fogTilesPerCamp) - camps.count { !it.value.destroyed }
+        var campsToAdd = (fogTiles.size / fogTilesPerCamp) - encampments.count { !it.destroyed }
 
         // First turn of the game add 1/3 of all possible camps
         if (gameInfo.turns == 1) {
@@ -102,9 +103,9 @@ class BarbarianManager : IsPartOfGameInfoSerialization {
         // Camps can't spawn within 7 tiles of each other or within 4 tiles of major civ capitals
         val tooCloseToCapitals = gameInfo.civilizations.filterNot { it.isBarbarian() || it.isSpectator() || it.cities.isEmpty() || it.isCityState() || it.getCapital() == null }
             .flatMap { it.getCapital()!!.getCenterTile().getTilesInDistance(4) }.toSet()
-        val tooCloseToCamps = camps
-            .flatMap { tileMap[it.key].getTilesInDistance(
-                    if (it.value.destroyed) 4 else 7
+        val tooCloseToCamps = encampments
+            .flatMap { tileMap[it.position].getTilesInDistance(
+                    if (it.destroyed) 4 else 7
             ) }.toSet()
 
         val viableTiles = fogTiles.filter {
@@ -118,7 +119,7 @@ class BarbarianManager : IsPartOfGameInfoSerialization {
 
         var tile: Tile?
         var addedCamps = 0
-        var biasCoast = Random().nextInt(6) == 0
+        var biasCoast = Random.Default.nextInt(6) == 0
 
         // Add the camps
         while (addedCamps < campsToAdd) {
@@ -136,7 +137,7 @@ class BarbarianManager : IsPartOfGameInfoSerialization {
             tile.changeImprovement(Constants.barbarianEncampment)
             val newCamp = Encampment(tile.position)
             newCamp.gameInfo = gameInfo
-            camps[newCamp.position] = newCamp
+            encampments.add(newCamp)
             notifyCivsOfBarbarianEncampment(tile)
             addedCamps++
 
@@ -145,7 +146,7 @@ class BarbarianManager : IsPartOfGameInfoSerialization {
                 // Remove some newly non-viable tiles
                 viableTiles.removeAll(tile.getTilesInDistance(7).toSet())
                 // Reroll bias
-                biasCoast = Random().nextInt(6) == 0
+                biasCoast = Random.Default.nextInt(6) == 0
             }
         }
     }
@@ -279,7 +280,7 @@ class Encampment() : IsPartOfGameInfoSerialization {
     /** When a barbarian is spawned, seed the counter for next spawn */
     private fun resetCountdown() {
         // Base 8-12 turns
-        countdown = 8 + Random().nextInt(5)
+        countdown = 8 + Random.Default.nextInt(5)
         // Quicker on Raging Barbarians
         if (gameInfo.gameParameters.ragingBarbarians)
             countdown /= 2
