@@ -2,7 +2,6 @@ package com.unciv.logic.civilization
 
 import com.badlogic.gdx.math.Vector2
 import com.unciv.Constants
-import com.unciv.UncivGame
 import com.unciv.json.HashMapVector2
 import com.unciv.logic.GameInfo
 import com.unciv.logic.IsPartOfGameInfoSerialization
@@ -32,7 +31,7 @@ import com.unciv.logic.map.mapunit.MapUnit
 import com.unciv.logic.map.tile.Tile
 import com.unciv.logic.trade.TradeRequest
 import com.unciv.models.Counter
-import com.unciv.models.metadata.GameParameters // Kdoc only
+import com.unciv.models.metadata.GameParameters
 import com.unciv.models.ruleset.Building
 import com.unciv.models.ruleset.Policy
 import com.unciv.models.ruleset.Victory
@@ -74,9 +73,7 @@ class Civilization : IsPartOfGameInfoSerialization {
     /** Returns an instance of WorkerAutomation valid for the duration of the current turn
      * This instance carries cached data common for all Workers of this civ */
     fun getWorkerAutomation(): WorkerAutomation {
-        val currentTurn = if (UncivGame.Current.isInitialized && UncivGame.Current.gameInfo != null) {
-            UncivGame.Current.gameInfo!!.turns
-        } else 0
+        val currentTurn = gameInfo.turns
         if (workerAutomationCache == null || workerAutomationCache!!.cachedForTurn != currentTurn)
             workerAutomationCache = WorkerAutomation(this, currentTurn)
         return workerAutomationCache!!
@@ -313,12 +310,18 @@ class Civilization : IsPartOfGameInfoSerialization {
     @Suppress("MemberVisibilityCanBePrivate")  // same visibility for overloads
     fun getProximity(civName: String) = proximity[civName] ?: Proximity.None
 
-    /** Returns only undefeated civs, aka the ones we care about */
+    /** Returns only undefeated civs, aka the ones we care about
+     *
+     *  Note: Currently the implementation of `updateAllyCivForCityState` will cause the diplomacy map of
+     *  city-states to contain the barbarians. Therefore, [getKnownCivs] will **not** list the barbarians
+     *  for major civs, but **will** do so for city-states after some gameplay.
+     */
     fun getKnownCivs() = diplomacy.values.asSequence().map { it.otherCiv() }.filter { !it.isDefeated() }
     fun knows(otherCivName: String) = diplomacy.containsKey(otherCivName)
     fun knows(otherCiv: Civilization) = knows(otherCiv.civName)
 
-    fun getCapital() = cities.firstOrNull { it.isCapital() }
+    fun getCapital(firstCityIfNoCapital: Boolean = false) = cities.firstOrNull { it.isCapital() } ?:
+        if (firstCityIfNoCapital) cities.firstOrNull() else null
     fun isHuman() = playerType == PlayerType.Human
     fun isAI() = playerType == PlayerType.AI
     fun isOneCityChallenger() = playerType == PlayerType.Human && gameInfo.gameParameters.oneCityChallenge
@@ -489,7 +492,12 @@ class Civilization : IsPartOfGameInfoSerialization {
         return tech.currentTechnology() == null && cities.isNotEmpty()
     }
 
-    fun getEquivalentBuilding(buildingName: String) = getEquivalentBuilding(gameInfo.ruleset.buildings[buildingName]!!)
+    fun getEquivalentBuilding(buildingName: String): Building {
+        val building = gameInfo.ruleset.buildings[buildingName]
+            ?: throw Exception("No building by the name of $buildingName exists!")
+        return getEquivalentBuilding(building)
+    }
+
     fun getEquivalentBuilding(baseBuilding: Building): Building {
         if (baseBuilding.replaces != null)
             return getEquivalentBuilding(baseBuilding.replaces!!)
@@ -655,15 +663,15 @@ class Civilization : IsPartOfGameInfoSerialization {
             diplomacyManager.updateHasOpenBorders()
         }
 
-        for (cityInfo in cities) {
-            cityInfo.setTransients(this) // must be before the city's setTransients because it depends on the tilemap, that comes from the currentPlayerCivInfo
+        for (city in cities) {
+            city.setTransients(this) // must be before the city's setTransients because it depends on the tilemap, that comes from the currentPlayerCivInfo
         }
 
         // Now that all tile transients have been updated, clean "worked" tiles that are not under the Civ's control
-        for (cityInfo in cities)
-            for (workedTile in cityInfo.workedTiles.toList())
+        for (city in cities)
+            for (workedTile in city.workedTiles.toList())
                 if (gameInfo.tileMap[workedTile].getOwner() != this)
-                    cityInfo.workedTiles.remove(workedTile)
+                    city.workedTiles.remove(workedTile)
 
         passThroughImpassableUnlocked = passableImpassables.isNotEmpty()
         // Cache whether this civ gets nonstandard terrain damage for performance reasons.
@@ -754,18 +762,24 @@ class Civilization : IsPartOfGameInfoSerialization {
         }
     }
 
-    fun addNotification(text: String, location: Vector2, category:NotificationCategory, vararg notificationIcons: String) {
+    // region addNotification
+    fun addNotification(text: String, category: NotificationCategory, vararg notificationIcons: String) =
+        addNotification(text, null, category, *notificationIcons)
+
+    fun addNotification(text: String, location: Vector2, category: NotificationCategory, vararg notificationIcons: String) =
         addNotification(text, LocationAction(location), category, *notificationIcons)
-    }
 
-    fun addNotification(text: String, category:NotificationCategory, vararg notificationIcons: String) = addNotification(text, null, category, *notificationIcons)
+    fun addNotification(text: String, action: NotificationAction, category: NotificationCategory, vararg notificationIcons: String) =
+        addNotification(text, listOf(action), category, *notificationIcons)
 
-    fun addNotification(text: String, action: NotificationAction?, category:NotificationCategory, vararg notificationIcons: String) {
+    fun addNotification(text: String, actions: Sequence<NotificationAction>, category:NotificationCategory, vararg notificationIcons: String) =
+        addNotification(text, actions.asIterable(), category, *notificationIcons)
+
+    fun addNotification(text: String, actions: Iterable<NotificationAction>?, category: NotificationCategory, vararg notificationIcons: String) {
         if (playerType == PlayerType.AI) return // no point in lengthening the saved game info if no one will read it
-        val arrayList = notificationIcons.toCollection(ArrayList())
-        notifications.add(Notification(text, arrayList,
-                if (action is LocationAction && action.locations.isEmpty()) null else action, category))
+        notifications.add(Notification(text, notificationIcons, actions, category))
     }
+    // endregion
 
     fun addCity(location: Vector2) {
         val newCity = CityFounder().foundCity(this, location)
@@ -802,12 +816,18 @@ class Civilization : IsPartOfGameInfoSerialization {
             city.cityConstructions.addBuilding(city.capitalCityIndicator())
             city.isBeingRazed = false // stop razing the new capital if it was being razed
         }
-        oldCapital?.cityConstructions?.removeBuilding(oldCapital.capitalCityIndicator())
+        // Don't use removeBuilding, since that rebuilds uniques and can generate errors when we have no capital
+        // We're going to recalc the uniques anyway once we move it to the new civ
+        oldCapital?.cityConstructions?.builtBuildings?.remove(oldCapital.capitalCityIndicator())
     }
 
     fun moveCapitalToNextLargest() {
         val availableCities = cities.filterNot { it.isCapital() }
-        if (availableCities.none()) return
+        if (availableCities.none()) {
+            moveCapitalTo(null)
+            return
+        }
+
         var newCapital = availableCities.filterNot { it.isPuppet }.maxByOrNull { it.population.population }
 
         if (newCapital == null) { // No non-puppets, take largest puppet and annex
