@@ -58,8 +58,8 @@ open class Tile : IsPartOfGameInfoSerialization {
             }
             roadOwner = city.civ.civName // only when taking control, otherwise last owner
         } else if (roadStatus != RoadStatus.None && owningCity != null) {
-            // previous tile owner still owns road, add to tracker
-            owningCity!!.civ.neutralRoads.add(this.position)
+            // Razing City! Remove owner
+            roadOwner = ""
         }
         owningCity = city
         isCityCenterInternal = getCity()?.location == position
@@ -497,13 +497,12 @@ open class Tile : IsPartOfGameInfoSerialization {
         if (isCityCenter()) return true
         val improvement = getUnpillagedTileImprovement()
         if (improvement != null && improvement.name in tileResource.getImprovements()
-                && (improvement.techRequired==null || civInfo.tech.isResearched(improvement.techRequired!!))) return true
+                && (improvement.techRequired == null || civInfo.tech.isResearched(improvement.techRequired!!))
+            ) return true
         // TODO: Generic-ify to unique
-        if (tileResource.resourceType==ResourceType.Strategic
-                && improvement!=null
-                && improvement.isGreatImprovement())
-            return true
-        return false
+        return (tileResource.resourceType == ResourceType.Strategic
+            && improvement != null
+            && improvement.isGreatImprovement())
     }
 
     // This should be the only adjacency function
@@ -533,9 +532,11 @@ open class Tile : IsPartOfGameInfoSerialization {
             naturalWonder -> true
             "Open terrain" -> !isRoughTerrain()
             "Rough terrain" -> isRoughTerrain()
+
             "Foreign Land", "Foreign" -> observingCiv != null && !isFriendlyTerritory(observingCiv)
             "Friendly Land", "Friendly" -> observingCiv != null && isFriendlyTerritory(observingCiv)
             "Enemy Land", "Enemy" -> observingCiv != null && isEnemyTerritory(observingCiv)
+
             resource -> observingCiv != null && hasViewableResource(observingCiv)
             "Water resource" -> isWater && observingCiv != null && hasViewableResource(observingCiv)
             "Natural Wonder" -> naturalWonder != null
@@ -822,7 +823,7 @@ open class Tile : IsPartOfGameInfoSerialization {
             else probability
     }
 
-    fun setTerrainFeatures(terrainFeatureList:List<String>) {
+    fun setTerrainFeatures(terrainFeatureList: List<String>) {
         terrainFeatures = terrainFeatureList
         terrainFeatureObjects = terrainFeatureList.mapNotNull { ruleset.terrains[it] }
         allTerrains = sequence {
@@ -844,7 +845,7 @@ open class Tile : IsPartOfGameInfoSerialization {
         terrainUniqueMap = newUniqueMap
     }
 
-    fun addTerrainFeature(terrainFeature:String) =
+    fun addTerrainFeature(terrainFeature: String) =
         setTerrainFeatures(ArrayList(terrainFeatures).apply { add(terrainFeature) })
 
     fun removeTerrainFeature(terrainFeature: String) =
@@ -853,6 +854,16 @@ open class Tile : IsPartOfGameInfoSerialization {
     fun removeTerrainFeatures() =
         setTerrainFeatures(listOf())
 
+    /** Clean stuff missing in [ruleset] - called from [TileMap.removeMissingTerrainModReferences]
+     *  Must be able to run before [setTransients] - and does not need to fix transients.
+     */
+    fun removeMissingTerrainModReferences(ruleset: Ruleset) {
+        terrainFeatures = terrainFeatures.filter { it in ruleset.terrains }
+        if (resource != null && resource !in ruleset.tileResources)
+            resource = null
+        if (improvement != null && improvement !in ruleset.tileImprovements)
+            changeImprovement(null)
+    }
 
     /** If the unit isn't in the ruleset we can't even know what type of unit this is! So check each place
      * This works with no transients so can be called from gameInfo.setTransients with no fear
@@ -884,7 +895,11 @@ open class Tile : IsPartOfGameInfoSerialization {
             return
         // http://well-of-souls.com/civ/civ5_improvements.html says that naval improvements are destroyed upon pillage
         //    and I can't find any other sources so I'll go with that
-        if (!isLand) { changeImprovement(null); return }
+        if (!isLand) {
+            changeImprovement(null)
+            owningCity?.reassignPopulationDeferred()
+            return
+        }
 
         // Setting turnsToImprovement might interfere with UniqueType.CreatesOneImprovement
         improvementFunctions.removeCreatesOneImprovementMarker()
@@ -903,6 +918,8 @@ open class Tile : IsPartOfGameInfoSerialization {
             else
                 roadIsPillaged = true
         }
+
+        owningCity?.reassignPopulationDeferred()
     }
 
     fun isPillaged(): Boolean {
@@ -916,6 +933,8 @@ open class Tile : IsPartOfGameInfoSerialization {
             improvementIsPillaged = false
         else
             roadIsPillaged = false
+
+        owningCity?.reassignPopulationDeferred()
     }
 
 
