@@ -126,7 +126,8 @@ class TileInfoImprovementFunctions(val tile: Tile) {
             // Can't build if the improvement specifically prevents building on some present feature
             improvement.getMatchingUniques(UniqueType.CannotBuildOnTile, stateForConditionals).any {
                     unique -> tile.matchesTerrainFilter(unique.params[0])
-            } -> false
+            } ->
+                false
 
             // Can't build if an improvement is only allowed to be built on specific tiles and this is not one of them
             // If multiple uniques of this type exists, we want all to match (e.g. Hill _and_ Forest would be meaningful)
