@@ -30,7 +30,7 @@ import kotlin.math.pow
 class Building : RulesetStatsObject(), INonPerpetualConstruction {
 
     override var requiredTech: String? = null
-    override var cost: Int = 0
+    override var cost: Int = -1
 
     var maintenance = 0
     private var percentStatBonus: Stats? = null
@@ -108,7 +108,7 @@ class Building : RulesetStatsObject(), INonPerpetualConstruction {
             && filterUniques?.invoke(it) ?: true
         }
 
-    /** used in CityScreen (CityInfoTable and ConstructionInfoTable) */
+    /** used in CityScreen (ConstructionInfoTable) */
     fun getDescription(city: City, showAdditionalInfo: Boolean): String {
         val stats = getStats(city)
         val translatedLines = ArrayList<String>() // Some translations require special handling
@@ -240,11 +240,9 @@ class Building : RulesetStatsObject(), INonPerpetualConstruction {
         if (cost > 0) {
             val stats = mutableListOf("$cost${Fonts.production}")
             if (canBePurchasedWithStat(null, Stat.Gold)) {
-                // We need what INonPerpetualConstruction.getBaseGoldCost calculates but without any game- or civ-specific modifiers
-                val buyCost = (30.0 * cost.toFloat().pow(0.75f) * hurryCostModifier.toPercent()).toInt() / 10 * 10
-                stats += "$buyCost${Fonts.gold}"
+                stats += "${getCivilopediaGoldCost()}${Fonts.gold}"
             }
-            textList += FormattedLine(stats.joinToString(", ", "{Cost}: "))
+            textList += FormattedLine(stats.joinToString("/", "{Cost}: "))
         }
 
         if (requiredTech != null)
@@ -386,8 +384,7 @@ class Building : RulesetStatsObject(), INonPerpetualConstruction {
         )
     }
 
-    override fun getBaseBuyCost(city: City, stat: Stat): Int? {
-        if (stat == Stat.Gold) return getBaseGoldCost(city.civ).toInt()
+    override fun getBaseBuyCost(city: City, stat: Stat): Float? {
         val conditionalState = StateForConditionals(civInfo = city.civ, city = city)
 
         return sequence {
@@ -404,12 +401,12 @@ class Building : RulesetStatsObject(), INonPerpetualConstruction {
                         it.params[1].toInt(),
                         it.params[4].toInt(),
                         city.civ.civConstructions.boughtItemsWithIncreasingPrice[name]
-                    )
+                    ) * city.civ.gameInfo.speed.statCostModifiers[stat]!!
                 }
             )
             yieldAll(city.getMatchingUniques(UniqueType.BuyBuildingsByProductionCost, conditionalState)
                 .filter { it.params[1] == stat.name && matchesFilter(it.params[0]) }
-                .map { getProductionCost(city.civ) * it.params[2].toInt() }
+                .map { (getProductionCost(city.civ) * it.params[2].toInt()).toFloat() }
             )
             if (city.getMatchingUniques(UniqueType.BuyBuildingsWithStat, conditionalState)
                 .any {
@@ -418,14 +415,14 @@ class Building : RulesetStatsObject(), INonPerpetualConstruction {
                     && city.matchesFilter(it.params[2])
                 }
             ) {
-                yield(city.civ.getEra().baseUnitBuyCost)
+                yield(city.civ.getEra().baseUnitBuyCost * city.civ.gameInfo.speed.statCostModifiers[stat]!!)
             }
             yieldAll(city.getMatchingUniques(UniqueType.BuyBuildingsForAmountStat, conditionalState)
                 .filter {
                     it.params[2] == stat.name
                     && matchesFilter(it.params[0])
                     && city.matchesFilter(it.params[3])
-                }.map { it.params[1].toInt() }
+                }.map { it.params[1].toInt() * city.civ.gameInfo.speed.statCostModifiers[stat]!! }
             )
         }.minOrNull()
     }
@@ -531,17 +528,19 @@ class Building : RulesetStatsObject(), INonPerpetualConstruction {
                 }
 
                 UniqueType.RequiresBuildingInSomeCities -> {
-                    val buildingName = unique.params[0]
+                    val buildingFilter = unique.params[0]
                     val numberOfCitiesRequired = unique.params[1].toInt()
                     val numberOfCitiesWithBuilding = civ.cities.count {
-                        it.cityConstructions.containsBuildingOrEquivalent(buildingName)
+                        it.cityConstructions.containsBuildingOrEquivalent(buildingFilter)
                     }
                     if (numberOfCitiesWithBuilding < numberOfCitiesRequired) {
-                        val equivalentBuildingName = civ.getEquivalentBuilding(buildingName).name
+                        val equivalentBuildingFilter = if (ruleSet.buildings.containsKey(buildingFilter))
+                            civ.getEquivalentBuilding(buildingFilter).name
+                        else buildingFilter
                         yield(
                                 // replace with civ-specific building for user
                                 RejectionReasonType.RequiresBuildingInSomeCities.toInstance(
-                                    unique.text.fillPlaceholders(equivalentBuildingName, numberOfCitiesRequired.toString()) +
+                                    unique.text.fillPlaceholders(equivalentBuildingFilter, numberOfCitiesRequired.toString()) +
                                             " ($numberOfCitiesWithBuilding/$numberOfCitiesRequired)"
                                 ) )
                     }
@@ -644,75 +643,14 @@ class Building : RulesetStatsObject(), INonPerpetualConstruction {
             getRejectionReasons(cityConstructions).none()
 
     override fun postBuildEvent(cityConstructions: CityConstructions, boughtWith: Stat?): Boolean {
-        val cityInfo = cityConstructions.city
-        val civInfo = cityInfo.civ
-
+        val civInfo = cityConstructions.city.civ
+        
         if (civInfo.gameInfo.spaceResources.contains(name)) {
             civInfo.victoryManager.currentsSpaceshipParts.add(name, 1)
             return true
         }
 
-        if (cityHealth > 0) {
-            // city built a building that increases health so add a portion of this added health that is
-            // proportional to the city's current health
-            cityConstructions.city.health += (cityHealth.toFloat() * cityConstructions.city.health.toFloat() / cityConstructions.city.getMaxHealth().toFloat()).toInt()
-        }
-
         cityConstructions.addBuilding(name)
-
-        /** Support for [UniqueType.CreatesOneImprovement] */
-        cityConstructions.applyCreateOneImprovement(this)
-
-        // "Provides a free [buildingName] [cityFilter]"
-        cityConstructions.addFreeBuildings()
-
-        val triggerNotificationText ="due to constructing [$name]"
-
-        for (unique in uniqueObjects)
-            if (unique.conditionals.none { it.type?.targetTypes?.contains(UniqueTarget.TriggerCondition)==true })
-                UniqueTriggerActivation.triggerCivwideUnique(unique, civInfo, cityConstructions.city, triggerNotificationText = triggerNotificationText)
-
-
-        for (unique in civInfo.getTriggeredUniques(UniqueType.TriggerUponConstructingBuilding, StateForConditionals(civInfo, cityInfo)))
-            if (unique.conditionals.any {it.type == UniqueType.TriggerUponConstructingBuilding && matchesFilter(it.params[0])})
-                UniqueTriggerActivation.triggerCivwideUnique(unique, cityInfo.civ, cityInfo, triggerNotificationText = triggerNotificationText)
-
-        for (unique in civInfo.getTriggeredUniques(UniqueType.TriggerUponConstructingBuildingCityFilter, StateForConditionals(cityInfo.civ, cityInfo)))
-            if (unique.conditionals.any {it.type == UniqueType.TriggerUponConstructingBuildingCityFilter
-                            && matchesFilter(it.params[0])
-                            && cityInfo.matchesFilter(it.params[1])})
-                UniqueTriggerActivation.triggerCivwideUnique(unique, cityInfo.civ, cityInfo, triggerNotificationText = triggerNotificationText)
-
-        if (hasUnique(UniqueType.EnemyLandUnitsSpendExtraMovement))
-            civInfo.cache.updateHasActiveEnemyMovementPenalty()
-
-        // Korean unique - apparently gives the same as the research agreement
-        if (isStatRelated(Stat.Science) && civInfo.hasUnique(UniqueType.TechBoostWhenScientificBuildingsBuiltInCapital))
-            civInfo.tech.addScience(civInfo.tech.scienceOfLast8Turns.sum() / 8)
-
-        // Happiness change _may_ invalidate best worked tiles (#9238), but if the building
-        // isn't bought (or the AI bought it) then reassignPopulation will run later in startTurn anyway
-        if (boughtWith != null && isStatRelated(Stat.Happiness)) {
-            // Happiness is global, so it could affect all cities
-            Concurrency.runOnNonDaemonThreadPool("reassignPopulationAllCities") {
-                for (city in civInfo.cities)
-                    city.reassignPopulationDeferred()
-            }
-        }
-
-        // Buying a building influencing tile yield may change CityFocus decisions
-        val uniqueTypesModifyingYields = listOf(
-            UniqueType.StatsFromTiles, UniqueType.StatsFromTilesWithout, UniqueType.StatsFromObject,
-            UniqueType.StatPercentFromObject, UniqueType.AllStatsPercentFromObject
-        )
-        if (boughtWith != null && uniqueTypesModifyingYields.any { hasUnique(it) }) {
-            cityConstructions.city.reassignPopulationDeferred()
-        }
-
-        cityConstructions.city.cityStats.update() // new building, new stats
-        civInfo.cache.updateCivResources() // this building/unit could be a resource-requiring one
-        civInfo.cache.updateCitiesConnectedToCapital(false) // could be a connecting building, like a harbor
-
         return true
     }
 
@@ -775,10 +713,7 @@ class Building : RulesetStatsObject(), INonPerpetualConstruction {
     }
 
     override fun requiresResource(resource: String): Boolean {
-        if (requiredResource == resource) return true
-        for (unique in getMatchingUniques(UniqueType.ConsumesResources)) {
-            if (unique.params[1] == resource) return true
-        }
+        if (resourceRequirementsInternal.contains(resource)) return true
         for (unique in getMatchingUniques(UniqueType.CostsResources)) {
             if (unique.params[1] == resource) return true
         }
